@@ -83,7 +83,7 @@ def import_torch_dataset(name, dataset, classes, state, model):
     :type dataset: torch.utils.data.DataLoader
     :param classes: an ordered list of strings representing class names
     :type classes: list
-    :param state: a 3D array of floats [layers,activations,neurons]. Length of activations must be the same as the number of images.
+    :param state: a 3D array of floats [layers,neurons,activations]. Length of activations must be the same as the number of images.
     :type state: Union[list,np.ndarray]
     :param model: the model structure
     :type model: deephys.deephys.Model
@@ -109,12 +109,6 @@ def import_torch_dataset(name, dataset, classes, state, model):
     )
 
 
-def _to_mat(d):
-    if isinstance(d, list):
-        return np.array(d)
-    return d
-
-
 def import_test_data(name, classes, state, model, pixel_data, ground_truths):
     """
     Prepare test results for Deephys
@@ -123,7 +117,7 @@ def import_test_data(name, classes, state, model, pixel_data, ground_truths):
     :type name: str
     :param classes: an ordered list of strings representing class names
     :type classes: list
-    :param state: a 3D array of floats [layers,activations,neurons]. Length of activations must be the same as the number of images.
+    :param state: a 3D array of floats [layers,neurons,activations]. Length of activations must be the same as the number of images.
     :type state: Union[list,np.ndarray]
     :param model: the model structure
     :type model: deephys.deephys.Model
@@ -135,7 +129,8 @@ def import_test_data(name, classes, state, model, pixel_data, ground_truths):
     :rtype: deephys.deephys.Test
     """
     imageList = []
-    state = list(map(_to_mat, state))
+    if isinstance(state, list):
+        state = np.array(state)
     if isinstance(pixel_data, list):
         pixel_data = torch.tensor(pixel_data)
     elif isinstance(pixel_data, np.ndarray):
@@ -157,7 +152,7 @@ def import_test_data(name, classes, state, model, pixel_data, ground_truths):
         chan_to_bytes = lambda chan: [bytes(row) for row in chan]
         im_to_bytes = lambda im: list(map(chan_to_bytes, im))
         im_as_list = image.numpy().astype(np.uint8).tolist()
-        im_activations = list(map(lambda l: l[i, :], state))
+        im_activations = state[:, :, i]
         imageList.append(
             ImageFile(
                 imageID=i,
